@@ -1,7 +1,9 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*-
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
  * Copyright (C) 2005 William Jon McCann <mccann@jhu.edu>
  *
+ * Licensed under the GNU General Public License Version 2
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -15,9 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- *
- * Authors: William Jon McCann <mccann@jhu.edu>
- *
  */
 
 #ifndef __GPM_IDLE_H
@@ -64,6 +63,8 @@ void        gpm_idle_reset               (GpmIdle    *idle);
 GpmIdleMode gpm_idle_get_mode            (GpmIdle    *idle);
 void        gpm_idle_set_mode            (GpmIdle    *idle,
                                           GpmIdleMode mode);
+void	    gpm_idle_set_check_cpu	 (GpmIdle    *idle,
+					  gboolean    check_type_cpu);
 
 void        gpm_idle_set_session_timeout (GpmIdle    *idle,
                                           guint       timeout);
