@@ -55,6 +55,7 @@
 #include "gpm-hal-monitor.h"
 #include "gpm-brightness.h"
 #include "gpm-tray-icon.h"
+#include "gpm-stock-icons.h"
 #include "gpm-manager.h"
 
 static void     gpm_manager_class_init (GpmManagerClass *klass);
@@ -92,6 +93,7 @@ struct GpmManagerPrivate
 	gint		 last_primary_percentage_change;
 
 	gboolean	 use_time_to_notify;
+	gboolean	 lid_is_closed;
 
 };
 
@@ -128,6 +130,8 @@ G_DEFINE_TYPE (GpmManager, gpm_manager, G_TYPE_OBJECT)
 #define		BATTERY_CRITICAL_REMAINING_TIME		(5 * 60)  /* 5 minutes  */
 #define		BATTERY_ACTION_REMAINING_TIME		(2 * 60)  /* 2 minutes  */
 
+#define		LAPTOP_PANEL_DIM_BRIGHTNESS		30 /* % */
+
 #undef DISABLE_ACTIONS_FOR_TESTING
 /*#define DISABLE_ACTIONS_FOR_TESTING 1*/
 
@@ -214,22 +218,68 @@ gpm_manager_can_shutdown (GpmManager *manager,
 	return TRUE;
 }
 
-/* Return 0..8 dependending on percent */
-static gint
+/* Return index value dependending on percent
+	00-10  = 000
+	10-30  = 020
+	30-50  = 040
+	50-70  = 060
+	70-90  = 080
+	90-100 = 100
+*/
+static char *
 get_icon_index_from_percent (gint percent)
 {
-	const gint NUM_INDEX = 8;
-	gint	   index;
-
-	index = ((percent + NUM_INDEX / 2) * NUM_INDEX ) / 100;
-	if (index < 0) {
-		return 0;
-	} else if (index > NUM_INDEX) {
-		return NUM_INDEX;
+	gpm_debug ("percent = %i", percent);
+	if (percent < 10) {
+		return "000";
+	} else if (percent < 30) {
+		return "020";
+	} else if (percent < 50) {
+		return "040";
+	} else if (percent < 70) {
+		return "060";
+	} else if (percent < 90) {
+		return "080";
 	}
-	return index;
+	return "100";
 }
 
+/* required, as UPS and primary icons have charged, charging and discharging icons.
+   must free retval */
+static char *
+get_stock_id_helper (GpmPowerBatteryStatus *device_status, const char *prefix)
+{
+	char *index;
+	char *filename = NULL;
+
+	if (!device_status->is_charging &&
+	    !device_status->is_discharging &&
+	    device_status->percentage_charge > 90) {
+
+		/* We have to do the additional check for 90% as
+		   some batteries are broken */
+		filename = g_strdup ("battery-charged");
+
+	} else if (device_status->is_charging) {
+
+		index = get_icon_index_from_percent (device_status->percentage_charge);
+		filename = g_strdup_printf ("%s-charging-%s", prefix, index);
+
+	} else if (device_status->is_discharging) {
+
+		index = get_icon_index_from_percent (device_status->percentage_charge);
+		filename = g_strdup_printf ("%s-discharging-%s", prefix, index);
+	} else {
+
+		/* We have a broken battery, not sure what to display here */
+		gpm_debug ("BROKEN BATTERY... Not sure what to do");
+		filename = g_strdup_printf ("%s-charging-000", prefix);
+	}
+	gpm_debug ("filename = %s", filename);
+	return filename;
+}
+
+/* must free retval */
 static char *
 get_stock_id (GpmManager *manager,
 	      int         icon_policy)
@@ -240,7 +290,7 @@ get_stock_id (GpmManager *manager,
 	GpmPowerBatteryStatus status_keyboard;
 	gboolean on_ac;
 	gboolean present;
-	int index;
+	gboolean use_fallback;
 
 	gpm_debug ("Getting stock icon for tray");
 
@@ -272,24 +322,22 @@ get_stock_id (GpmManager *manager,
 	gpm_power_get_on_ac (manager->priv->power, &on_ac, NULL);
 
 	/* we try CRITICAL: PRIMARY, UPS, MOUSE, KEYBOARD */
+	gpm_debug ("Trying CRITICAL: primary, ups, mouse, keyboard");
 	if (status_primary.is_present &&
 	    status_primary.percentage_charge < BATTERY_LOW_PERCENTAGE) {
-		index = get_icon_index_from_percent (status_primary.percentage_charge);
-		if (on_ac) {
-			return g_strdup_printf ("gnome-power-ac-%d-of-8", index);
-		} else {
-			return g_strdup_printf ("gnome-power-bat-%d-of-8", index);
-		}
+		return get_stock_id_helper (&status_primary, ICON_PREFIX_PRIMARY);
+
 	} else if (status_ups.is_present &&
 		   status_ups.percentage_charge < BATTERY_LOW_PERCENTAGE) {
-		index = get_icon_index_from_percent (status_ups.percentage_charge);
-		return g_strdup_printf ("gnome-power-ups-%d-of-8", index);
+		return get_stock_id_helper (&status_ups, ICON_PREFIX_UPS);
+
 	} else if (status_mouse.is_present &&
 		   status_mouse.percentage_charge < BATTERY_LOW_PERCENTAGE) {
-		return g_strdup_printf ("gnome-power-mouse");
+		return g_strdup_printf (GPM_STOCK_MOUSE_LOW);
+
 	} else if (status_keyboard.is_present &&
 		   status_keyboard.percentage_charge < BATTERY_LOW_PERCENTAGE) {
-		return g_strdup_printf ("gnome-power-keyboard");
+		return g_strdup_printf (GPM_STOCK_KEYBOARD_LOW);
 	}
 
 	if (icon_policy == GPM_ICON_POLICY_CRITICAL) {
@@ -298,18 +346,14 @@ get_stock_id (GpmManager *manager,
 	}
 
 	/* we try (DIS)CHARGING: PRIMARY, UPS */
+	gpm_debug ("Trying CHARGING: primary, ups");
 	if (status_primary.is_present &&
-	    (status_primary.is_charging || status_primary.is_discharging)) {
-		index = get_icon_index_from_percent (status_primary.percentage_charge);
-		if (on_ac) {
-			return g_strdup_printf ("gnome-power-ac-%d-of-8", index);
-		} else {
-			return g_strdup_printf ("gnome-power-bat-%d-of-8", index);
-		}
+	    (status_primary.is_charging || status_primary.is_discharging) ) {
+		return get_stock_id_helper (&status_primary, ICON_PREFIX_PRIMARY);
+
 	} else if (status_ups.is_present &&
-		   (status_ups.is_charging || status_ups.is_charging)) {
-		index = get_icon_index_from_percent (status_ups.percentage_charge);
-		return g_strdup_printf ("gnome-power-ups-%d-of-8", index);
+		   (status_ups.is_charging || status_ups.is_discharging) ) {
+		return get_stock_id_helper (&status_ups, ICON_PREFIX_UPS);
 	}
 
 	/* Check if we should just show the icon all the time */
@@ -319,24 +363,27 @@ get_stock_id (GpmManager *manager,
 	}
 
 	/* we try PRESENT: PRIMARY, UPS */
+	gpm_debug ("Trying PRESENT: primary, ups");
 	if (status_primary.is_present) {
-		index = get_icon_index_from_percent (status_primary.percentage_charge);
-		if (on_ac) {
-			if (!status_primary.is_charging && !status_primary.is_discharging) {
-				/* if we are not charging, then don't display the 'flash' */
-				return g_strdup ("gnome-power-ac-charged");
-			}
-			return g_strdup_printf ("gnome-power-ac-%d-of-8", index);
-		} else {
-			return g_strdup_printf ("gnome-power-bat-%d-of-8", index);
-		}
+		return get_stock_id_helper (&status_primary, ICON_PREFIX_PRIMARY);
+
 	} else if (status_ups.is_present) {
-		index = get_icon_index_from_percent (status_ups.percentage_charge);
-		return g_strdup_printf ("gnome-power-ups-%d-of-8", index);
+		return get_stock_id_helper (&status_ups, ICON_PREFIX_UPS);
 	}
 
-	/* we fallback to the ac_adapter icon */
-	return g_strdup_printf ("gnome-dev-acadapter");
+	/* we have a falback here, so that desktops by default do not have
+	   the icon, but it can be "forced" */
+	use_fallback = gconf_client_get_bool (manager->priv->gconf_client,
+					      GPM_PREF_USE_ICON_DESKTOPS,
+					      NULL);
+	if (use_fallback) {
+		/* we fallback to the ac_adapter icon */
+		gpm_debug ("Using fallback");
+		return g_strdup_printf (GPM_STOCK_AC_ADAPTER);
+	}
+	/* no icon! */
+	gpm_debug ("No devices present, and no fallback, so no icon displayed.");
+	return NULL;
 }
 
 static void
@@ -491,11 +538,83 @@ maybe_notify_on_ac_changed (GpmManager *manager,
 	}
 }
 
+static gboolean
+manager_do_we_screensave (GpmManager *manager,
+			  const char *policy)
+{
+	gboolean do_lock;
+	gboolean use_ss_setting;
+	/* This allows us to over-ride the custom lock settings set in gconf
+	   with a system default set in gnome-screensaver.
+	   See bug #331164 for all the juicy details. :-) */
+	use_ss_setting = gconf_client_get_bool (manager->priv->gconf_client,
+						GPM_PREF_LOCK_USE_SCREENSAVER,
+						NULL);
+	if (use_ss_setting) {
+		do_lock = gpm_screensaver_lock_enabled ();
+		gpm_debug ("Using ScreenSaver settings (%i)", do_lock);
+	} else {
+		do_lock = gconf_client_get_bool (manager->priv->gconf_client,
+						 policy, NULL);
+		gpm_debug ("Using constom locking settings (%i)", do_lock);
+	}
+	return do_lock;
+}
+
+static gboolean
+gpm_manager_blank_screen (GpmManager *manager,
+			  GError    **noerror)
+{
+	gboolean do_lock;
+	gboolean ret = TRUE;
+
+	do_lock = manager_do_we_screensave (manager,
+					    GPM_PREF_LOCK_ON_BLANK_SCREEN);
+	if (do_lock) {
+		gpm_screensaver_lock ();
+	}
+	/* We give the options to enable DPMS because some laptops do
+	 * not turn off the LCD backlight when the lid is closed. 
+	 * See http://bugzilla.gnome.org/show_bug.cgi?id=321313 */
+	GError     *error = NULL;
+	gpm_dpms_set_mode (manager->priv->dpms, GPM_DPMS_MODE_OFF, &error);
+	if (error) {
+		gpm_debug ("Unable to set DPMS mode: %s", error->message);
+		g_error_free (error);
+		ret = FALSE;
+	}
+	return ret;
+}
+
+static gboolean
+gpm_manager_unblank_screen (GpmManager *manager,
+			    GError    **noerror)
+{
+	gboolean  do_lock;
+	gboolean  ret = TRUE;
+	GError   *error;
+
+	error = NULL;
+	gpm_dpms_set_mode (manager->priv->dpms, GPM_DPMS_MODE_ON, &error);
+	if (error) {
+		gpm_debug ("Unable to set DPMS mode: %s", error->message);
+		g_error_free (error);
+		ret = FALSE;
+	}
+
+	do_lock = manager_do_we_screensave (manager,
+					    GPM_PREF_LOCK_ON_BLANK_SCREEN);
+	if (do_lock) {
+		gpm_screensaver_poke ();
+	}
+	return ret;
+}
+
 static void
 manager_policy_do (GpmManager *manager,
 		   const char *policy)
 {
-	char *action;
+	char     *action;
 
 	gpm_debug ("policy: %s", policy);
 
@@ -504,22 +623,29 @@ manager_policy_do (GpmManager *manager,
 	if (! action) {
 		return;
 	}
+
 	if (strcmp (action, ACTION_NOTHING) == 0) {
+
 		gpm_debug ("*ACTION* Doing nothing");
 
 	} else if (strcmp (action, ACTION_SUSPEND) == 0) {
-		gpm_debug ("*ACTION* Suspend");
 
+		gpm_debug ("*ACTION* Suspend");
 		gpm_manager_suspend (manager, NULL);
 
 	} else if (strcmp (action, ACTION_HIBERNATE) == 0) {
-		gpm_debug ("*ACTION* Hibernate");
 
+		gpm_debug ("*ACTION* Hibernate");
 		gpm_manager_hibernate (manager, NULL);
 
-	} else if (strcmp (action, ACTION_SHUTDOWN) == 0) {
-		gpm_debug ("*ACTION* Shutdown");
+	} else if (strcmp (action, ACTION_BLANK) == 0) {
 
+		gpm_debug ("*ACTION* Blank");
+		gpm_manager_blank_screen (manager, NULL);
+
+	} else if (strcmp (action, ACTION_SHUTDOWN) == 0) {
+
+		gpm_debug ("*ACTION* Shutdown");
 		gpm_manager_shutdown (manager, NULL);
 
 	} else {
@@ -527,7 +653,6 @@ manager_policy_do (GpmManager *manager,
 	}
 
 	g_free (action);
-
 }
 
 gboolean
@@ -617,9 +742,9 @@ gboolean
 gpm_manager_hibernate (GpmManager *manager,
 		       GError    **error)
 {
-	gboolean should_lock = gpm_screensaver_lock_enabled ();
 	gboolean allowed;
 	gboolean ret;
+	gboolean do_lock;
 
 	gpm_manager_can_hibernate (manager, &allowed, NULL);
 
@@ -632,7 +757,9 @@ gpm_manager_hibernate (GpmManager *manager,
 		return FALSE;
 	}
 
-	if (should_lock) {
+	do_lock = manager_do_we_screensave (manager,
+					    GPM_PREF_LOCK_ON_HIBERNATE);
+	if (do_lock) {
 		gpm_screensaver_lock ();
 	}
 
@@ -642,24 +769,27 @@ gpm_manager_hibernate (GpmManager *manager,
 	ret = gpm_hal_hibernate ();
 	if (! ret) {
 		char *message;
-		message = g_strdup_printf (_("HAL failed to %s. "
-					     "Check the <a href=\"%s\">FAQ page</a> for common problems."),
-					     _("hibernate"), GPM_FAQ_URL);
-
-		gpm_tray_icon_notify (GPM_TRAY_ICON (manager->priv->tray_icon),
-				      5000,
-				      _("Hibernate Problem"),
-				      NULL,
-				      message);
-		g_free (message);
+		gboolean show_notify;
+		/* We only show the HAL failed notification if set in gconf */
+		show_notify = gconf_client_get_bool (manager->priv->gconf_client,
+						     GPM_PREF_NOTIFY_HAL_ERROR, NULL);
+		if (show_notify) {
+			message = g_strdup_printf (_("HAL failed to %s. "
+						     "Check the <a href=\"%s\">FAQ page</a> for common problems."),
+						     _("hibernate"), GPM_FAQ_URL);
+			gpm_tray_icon_notify (GPM_TRAY_ICON (manager->priv->tray_icon),
+					      5000,
+					      _("Hibernate Problem"),
+					      NULL,
+					      message);
+			g_free (message);
+		}
 	}
 
-	gpm_networkmanager_wake ();
-
-	/* Poke GNOME ScreenSaver so the dialogue is displayed */
-	if (should_lock) {
+	if (do_lock) {
 		gpm_screensaver_poke ();
 	}
+	gpm_networkmanager_wake ();
 
 	return ret;
 }
@@ -668,9 +798,9 @@ gboolean
 gpm_manager_suspend (GpmManager *manager,
 		     GError    **error)
 {
-	gboolean should_lock = gpm_screensaver_lock_enabled ();
 	gboolean allowed;
 	gboolean ret;
+	gboolean do_lock;
 
 	gpm_manager_can_suspend (manager, &allowed, NULL);
 
@@ -683,7 +813,9 @@ gpm_manager_suspend (GpmManager *manager,
 		return FALSE;
 	}
 
-	if (should_lock) {
+	do_lock = manager_do_we_screensave (manager,
+					    GPM_PREF_LOCK_ON_SUSPEND);
+	if (do_lock) {
 		gpm_screensaver_lock ();
 	}
 
@@ -693,24 +825,27 @@ gpm_manager_suspend (GpmManager *manager,
 	ret = gpm_hal_suspend (0);
 	if (! ret) {
 		char *message;
-		message = g_strdup_printf (_("Your computer failed to %s.\n"
-					     "Check the <a href=\"%s\">FAQ page</a> for common problems."),
-					     _("suspend"), GPM_FAQ_URL);
-
-		gpm_tray_icon_notify (GPM_TRAY_ICON (manager->priv->tray_icon),
-				      5000,
-				      _("Suspend Problem"),
-				      NULL,
-				      message);
-		g_free (message);
+		gboolean show_notify;
+		/* We only show the HAL failed notification if set in gconf */
+		show_notify = gconf_client_get_bool (manager->priv->gconf_client,
+						     GPM_PREF_NOTIFY_HAL_ERROR, NULL);
+		if (show_notify) {
+			message = g_strdup_printf (_("Your computer failed to %s.\n"
+						     "Check the <a href=\"%s\">FAQ page</a> for common problems."),
+						     _("suspend"), GPM_FAQ_URL);
+			gpm_tray_icon_notify (GPM_TRAY_ICON (manager->priv->tray_icon),
+					      5000,
+					      _("Suspend Problem"),
+					      NULL,
+					      message);
+			g_free (message);
+		}
 	}
 
-	gpm_networkmanager_wake ();
-
-	/* Poke GNOME ScreenSaver so the dialogue is displayed */
-	if (should_lock) {
+	if (do_lock) {
 		gpm_screensaver_poke ();
 	}
+	gpm_networkmanager_wake ();
 
 	return ret;
 }
@@ -721,7 +856,7 @@ idle_changed_cb (GpmIdle    *idle,
 		 GpmManager *manager)
 {
 	GError  *error;
-	gboolean res;
+	gboolean do_laptop_dim;
 
 	switch (mode) {
 	case GPM_IDLE_MODE_NORMAL:
@@ -729,11 +864,20 @@ idle_changed_cb (GpmIdle    *idle,
 
 		/* deactivate display power management */
 		error = NULL;
-		res = gpm_dpms_set_active (manager->priv->dpms, FALSE, &error);
+		gpm_dpms_set_active (manager->priv->dpms, FALSE, &error);
 		if (error) {
 			gpm_debug ("Unable to set DPMS active: %s", error->message);
 		}
 
+		/* Should we dim the screen? */
+		do_laptop_dim = gconf_client_get_bool (manager->priv->gconf_client,
+						       GPM_PREF_IDLE_DIM_SCREEN, NULL);
+		if (do_laptop_dim) {
+			/* resume to the previous brightness */
+			gpm_brightness_level_resume (manager->priv->brightness);
+		}
+
+		/* sync timeouts */
 		sync_dpms_policy (manager);
 
 		break;
@@ -743,11 +887,20 @@ idle_changed_cb (GpmIdle    *idle,
 
 		/* activate display power management */
 		error = NULL;
-		res = gpm_dpms_set_active (manager->priv->dpms, TRUE, &error);
+		gpm_dpms_set_active (manager->priv->dpms, TRUE, &error);
 		if (error) {
 			gpm_debug ("Unable to set DPMS active: %s", error->message);
 		}
 
+		/* Should we resume the screen? */
+		do_laptop_dim = gconf_client_get_bool (manager->priv->gconf_client,
+						       GPM_PREF_IDLE_DIM_SCREEN, NULL);
+		if (do_laptop_dim) {
+			/* save this brightness and dim the screen, fixes #328564 */
+			gpm_brightness_level_save (manager->priv->brightness,
+						   LAPTOP_PANEL_DIM_BRIGHTNESS);
+		}
+
 		/* sync timeouts */
 		sync_dpms_policy (manager);
 
@@ -756,7 +909,7 @@ idle_changed_cb (GpmIdle    *idle,
 		gpm_debug ("Idle state changed: SYSTEM");
 
 		/* can only be hibernate or suspend */
-		manager_policy_do (manager, GPM_PREF_BATTERY_CRITICAL);
+		manager_policy_do (manager, GPM_PREF_SLEEP_TYPE);
 
 		break;
 	default:
@@ -815,43 +968,28 @@ static void
 lid_button_pressed (GpmManager	 *manager,
 		    gboolean	  state)
 {
-	GpmDpmsMode mode;
-	GError     *error;
-	gboolean    res;
-	gboolean    on_ac;
+	gboolean  on_ac;
 
 	gpm_power_get_on_ac (manager->priv->power, &on_ac, NULL);
 
 	gpm_debug ("button changed: %d", state);
 
-	/*
-	 * We enable/disable DPMS because some laptops do
-	 * not turn off the LCD backlight when the lid
-	 * is closed. See
-	 * http://bugzilla.gnome.org/show_bug.cgi?id=321313
-	 */
-	if (state) {
-		/*
-		 * We only do a policy event when the lid is CLOSED
-		 * and we are on battery power. See
-		 * http://bugzilla.gnome.org/show_bug.cgi?id=329512
-		 */
-		if (on_ac) {
-			gpm_debug ("Ignoring policy as on AC");
-		} else {
-			gpm_debug ("Performing policy as on battery");
-			manager_policy_do (manager, GPM_PREF_BUTTON_LID);
-		}
-		mode = GPM_DPMS_MODE_OFF;
-	} else {
-		mode = GPM_DPMS_MODE_ON;
-	}
+	/* We keep track of the lid state so we can do the 
+	   lid close on battery action if the ac_adapter is removed when the laptop
+	   is closed. Fixes #331655 */
+	manager->priv->lid_is_closed = state;
 
-	error = NULL;
-	res = gpm_dpms_set_mode (manager->priv->dpms, mode, &error);
-	if (error) {
-		gpm_debug ("Unable to set DPMS mode: %s", error->message);
-		g_error_free (error);
+	if (state) {
+		if (on_ac) {
+			gpm_debug ("Performing AC policy");
+			manager_policy_do (manager, GPM_PREF_AC_BUTTON_LID);
+		} else {
+			gpm_debug ("Performing battery policy");
+			manager_policy_do (manager, GPM_PREF_BATTERY_BUTTON_LID);
+		}
+	} else {
+		/* we turn the lid dpms back on unconditionally */
+		gpm_manager_unblank_screen (manager, NULL);
 	}
 }
 
@@ -904,6 +1042,12 @@ power_on_ac_changed_cb (GpmPower   *power,
 {
 	gpm_debug ("Setting on-ac: %d", on_ac);
 
+	/* If we are on AC power we should show warnings again */
+	if (on_ac) {
+		gpm_debug ("Resetting last_primary_warning to NONE");
+		manager->priv->last_primary_warning = GPM_WARNING_NONE;
+	}
+
 	tray_icon_update (manager);
 
 	maybe_notify_on_ac_changed (manager, on_ac);
@@ -911,8 +1055,14 @@ power_on_ac_changed_cb (GpmPower   *power,
 
 	gpm_debug ("emitting on-ac-changed : %i", on_ac);
 	g_signal_emit (manager, signals [ON_AC_CHANGED], 0, on_ac);
-}
 
+	/* We do the lid close on battery action if the ac_adapter is removed
+	   when the laptop is closed and on battery. Fixes #331655 */
+	if (! on_ac && manager->priv->lid_is_closed) {
+		gpm_debug ("Doing battery policy when lid closed and power removed");
+		manager_policy_do (manager, GPM_PREF_BATTERY_BUTTON_LID);
+	}
+}
 
 static GpmWarning
 gpm_manager_get_warning_type (GpmPowerBatteryStatus *battery_status,
@@ -973,29 +1123,34 @@ battery_low_get_title (GpmWarning warning_type)
 
 	} else if (warning_type == GPM_WARNING_DISCHARGING) {
 
-		title = _("Power Warning");
+		title = _("Power Information");
 
 	}
 
 	return title;
 }
 
+static gboolean
+manager_critical_action_do (GpmManager *manager)
+{
+	manager_policy_do (manager, GPM_PREF_BATTERY_CRITICAL);
+	return FALSE;
+}
+
 /* performs critical action is required, and displays notifications */
 static void
 battery_status_changed_primary (GpmManager	      *manager,
 			        GpmPowerBatteryKind    battery_kind,
 				GpmPowerBatteryStatus *battery_status)
 {
-	GpmWarning warning_type;
-	gboolean show_notify;
-	char *message = NULL;
-	char *remaining = NULL;
+	GpmWarning  warning_type;
+	gboolean    show_notify;
+	char       *message = NULL;
+	char       *remaining = NULL;
 	const char *title = NULL;
+	gboolean    on_ac;
 
-	if (battery_status->percentage_charge != manager->priv->last_primary_percentage_change) {
-		/* should we fire an event or something? */
-		manager->priv->last_primary_percentage_change = battery_status->percentage_charge;
-	}
+	gpm_power_get_on_ac (manager->priv->power, &on_ac, NULL);
 
 	/* If we are charging we should show warnings again as soon as we discharge again */
 	if (battery_status->is_charging) {
@@ -1021,11 +1176,21 @@ battery_status_changed_primary (GpmManager	      *manager,
 		return;
 	}
 
+	if (battery_status->percentage_charge != manager->priv->last_primary_percentage_change) {
+		/* should we fire an event or something? */
+		manager->priv->last_primary_percentage_change = battery_status->percentage_charge;
+	}
+
 	if (! battery_status->is_discharging) {
 		gpm_debug ("%s is not discharging", battery_kind_to_string (battery_kind));
 		return;
 	}
 
+	if (on_ac) {
+		gpm_debug ("Computer marked as on_ac.");
+		return;
+	}
+
 	warning_type = gpm_manager_get_warning_type (battery_status, manager->priv->use_time_to_notify);
 
 	/* no point continuing, we are not going to match */
@@ -1035,15 +1200,40 @@ battery_status_changed_primary (GpmManager	      *manager,
 	}
 
 	if (warning_type == GPM_WARNING_ACTION) {
-		gpm_tray_icon_notify (GPM_TRAY_ICON (manager->priv->tray_icon),
-				      5000,
-				      _("Critical action"),
-				      NULL,
-				      _("The battery is below the critical level and "
-					"this computer is about to shutdown."));
+		const char *warning = NULL;
+		const char *action;
+
+		/* we have to do different warnings depending on the policy */
+		action = gconf_client_get_string (manager->priv->gconf_client,
+						  GPM_PREF_BATTERY_CRITICAL, NULL);
+
+		/* FIXME: we should probably convert to an ENUM type, and use that */
+		if (strcmp (action, ACTION_NOTHING) == 0) {
+			warning = _("The battery is below the critical level and "
+				    "this computer will <b>power-off</b> when the "
+				    "battery becomes completely empty.");
+		} else if (strcmp (action, ACTION_SUSPEND) == 0) {
+			warning = _("The battery is below the critical level and "
+				    "this computer is about to suspend.<br>"
+				    "<b>NOTE:</b> A small amount of power is required "
+				    "to keep your computer in a suspended state.");
+		} else if (strcmp (action, ACTION_HIBERNATE) == 0) {
+			warning = _("The battery is below the critical level and "
+				    "this computer is about to hibernate.");
+		} else if (strcmp (action, ACTION_SHUTDOWN) == 0) {
+			warning = _("The battery is below the critical level and "
+				    "this computer is about to shutdown.");
+		}
+
+		if (warning) {
+			gpm_tray_icon_notify (GPM_TRAY_ICON (manager->priv->tray_icon),
+					      5000,
+					      _("Critical action"),
+					      NULL,
+					      warning);
+		}
 		/* wait 10 seconds for user-panic */
-		g_usleep (1000 * 1000 * 10);
-		manager_policy_do (manager, GPM_PREF_BATTERY_CRITICAL);
+		g_timeout_add (1000*10, (GSourceFunc) manager_critical_action_do, manager);
 	}
 
 	/* Always check if we already notified the user */
@@ -1361,6 +1551,7 @@ callback_gconf_key_changed (GConfClient *client,
 	}
 }
 
+#if ACTIONS_MENU_ENABLED
 static void
 gpm_manager_tray_icon_hibernate (GpmManager   *manager,
 				 GpmTrayIcon  *tray)
@@ -1376,6 +1567,7 @@ gpm_manager_tray_icon_suspend (GpmManager   *manager,
 	gpm_debug ("Received supend signal from tray icon");
 	gpm_manager_suspend (manager, NULL);
 }
+#endif
 
 static void
 hal_battery_removed_cb (GpmHalMonitor *monitor,
@@ -1391,8 +1583,11 @@ static void
 gpm_manager_init (GpmManager *manager)
 {
 	gboolean on_ac;
+	gboolean use_time;
+	gboolean check_type_cpu;
+#if ACTIONS_MENU_ENABLED
 	gboolean enabled;
-
+#endif
 	manager->priv = GPM_MANAGER_GET_PRIVATE (manager);
 
 	manager->priv->gconf_client = gconf_client_get_default ();
@@ -1405,6 +1600,9 @@ gpm_manager_init (GpmManager *manager)
 	g_signal_connect (manager->priv->power, "battery-status-changed",
 			  G_CALLBACK (power_battery_status_changed_cb), manager);
 
+	/* FIXME: We shouldn't assume the lid is open at startup */
+	manager->priv->lid_is_closed = FALSE;
+
 	/* we need these to refresh the tooltip and icon */
 	g_signal_connect (manager->priv->power, "battery-removed",
 			  G_CALLBACK (hal_battery_removed_cb), manager);
@@ -1427,11 +1625,18 @@ gpm_manager_init (GpmManager *manager)
 	g_signal_connect (manager->priv->idle, "changed",
 			  G_CALLBACK (idle_changed_cb), manager);
 
+	/* set up the check_type_cpu, so we can disable the CPU load check */
+	check_type_cpu = gconf_client_get_bool (manager->priv->gconf_client,
+						GPM_PREF_IDLE_CHECK_CPU,
+						NULL);
+	gpm_idle_set_check_cpu (manager->priv->idle, check_type_cpu);
+
 	manager->priv->dpms = gpm_dpms_new ();
 
 	gpm_debug ("creating new tray icon");
 	manager->priv->tray_icon = gpm_tray_icon_new ();
 
+#if ACTIONS_MENU_ENABLED
 	gpm_manager_can_suspend (manager, &enabled, NULL);
 	gpm_tray_icon_enable_suspend (GPM_TRAY_ICON (manager->priv->tray_icon), enabled);
 	gpm_manager_can_hibernate (manager, &enabled, NULL);
@@ -1447,6 +1652,7 @@ gpm_manager_init (GpmManager *manager)
 				 G_CALLBACK (gpm_manager_tray_icon_hibernate),
 				 manager,
 				 G_CONNECT_SWAPPED);
+#endif
 
 	/* coldplug so we are in the correct state at startup */
 	sync_dpms_policy (manager);
@@ -1456,19 +1662,30 @@ gpm_manager_init (GpmManager *manager)
 	g_signal_connect (manager->priv->dpms, "mode-changed",
 			  G_CALLBACK (dpms_mode_changed_cb), manager);
 
-	/* we don't want to be notified on coldplug if we are on battery power */
-	manager->priv->last_primary_warning = GPM_WARNING_DISCHARGING;
-	
 	/* we want all notifications */
 	manager->priv->last_ups_warning = GPM_WARNING_NONE;
 	manager->priv->last_mouse_warning = GPM_WARNING_NONE;
 	manager->priv->last_keyboard_warning = GPM_WARNING_NONE;
 	manager->priv->last_pda_warning = GPM_WARNING_NONE;
+	manager->priv->last_primary_warning = GPM_WARNING_NONE;
 	manager->priv->last_primary_percentage_change = 0;
 
-	/* We can change this easily if	this doesn't work in real-world
-	 * conditions, or perhaps make this a gconf configurable. */
-	manager->priv->use_time_to_notify = TRUE;
+	/* We don't want to be notified on coldplug if we are on battery power
+	   this should fix #332322 */
+	if (! on_ac) {
+		manager->priv->last_primary_warning = GPM_WARNING_DISCHARGING;
+	}
+
+	/* We can disable this if the ACPI BIOS is fucked, and the
+	   time_remaining is therefore inaccurate or just plain wrong. */
+	use_time = gconf_client_get_bool (manager->priv->gconf_client,
+					  GPM_PREF_USE_TIME_POLICY, NULL);
+	if (use_time) {
+		gpm_debug ("Using per-time notification policy");
+	} else {
+		gpm_debug ("Using percentage notification policy");
+	}
+	manager->priv->use_time_to_notify = use_time;
 }
 
 static void
