@@ -1,7 +1,9 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*-
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
  * Copyright (C) 2005 William Jon McCann <mccann@jhu.edu>
  *
+ * Licensed under the GNU General Public License Version 2
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -15,9 +17,6 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- *
- * Authors: William Jon McCann <mccann@jhu.edu>
- *
  */
 
 #ifndef __GPM_MANAGER_H
@@ -26,12 +25,6 @@
 #include <glib-object.h>
 #include <dbus/dbus-glib.h>
 
-/*
- * Enable this for GPM to use the system bus and share it.
- * This cannot be turned on until 
- * https://bugs.freedesktop.org/show_bug.cgi?id=4637 is fixed.
- */
-#define GPM_SYSTEM_BUS 			FALSE
 #define	GPM_DBUS_SERVICE		"org.gnome.PowerManager"
 #define	GPM_DBUS_PATH			"/org/gnome/PowerManager"
 #define	GPM_DBUS_INTERFACE		"org.gnome.PowerManager"
@@ -63,6 +56,15 @@ typedef struct
                                                      const char *mode);
 } GpmManagerClass;
 
+typedef enum
+{
+        GPM_MANAGER_ERROR_GENERAL
+} GpmManagerError;
+
+#define GPM_MANAGER_ERROR gpm_manager_error_quark ()
+
+GQuark         gpm_manager_error_quark      (void);
+
 GType          gpm_manager_get_type         (void);
 
 GpmManager   * gpm_manager_new              (void);
@@ -87,9 +89,12 @@ gboolean       gpm_manager_set_dpms_mode    (GpmManager    *manager,
                                              const char    *mode,
                                              GError       **error);
 
-void           gpm_manager_suspend          (GpmManager    *manager);
-void           gpm_manager_hibernate        (GpmManager    *manager);
-void           gpm_manager_shutdown         (GpmManager    *manager);
+gboolean       gpm_manager_suspend          (GpmManager    *manager,
+                                             GError       **error);
+gboolean       gpm_manager_hibernate        (GpmManager    *manager,
+                                             GError       **error);
+gboolean       gpm_manager_shutdown         (GpmManager    *manager,
+                                             GError       **error);
 
 G_END_DECLS
 
