@@ -204,48 +204,3 @@ gpm_marshal_VOID__INT_LONG_BOOLEAN_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* NONE:INT,LONG,BOOLEAN,BOOLEAN,BOOLEAN,BOOLEAN (gpm-marshal.list:6) */
-void
-gpm_marshal_VOID__INT_LONG_BOOLEAN_BOOLEAN_BOOLEAN_BOOLEAN (GClosure     *closure,
-                                                            GValue       *return_value,
-                                                            guint         n_param_values,
-                                                            const GValue *param_values,
-                                                            gpointer      invocation_hint,
-                                                            gpointer      marshal_data)
-{
-  typedef void (*GMarshalFunc_VOID__INT_LONG_BOOLEAN_BOOLEAN_BOOLEAN_BOOLEAN) (gpointer     data1,
-                                                                               gint         arg_1,
-                                                                               glong        arg_2,
-                                                                               gboolean     arg_3,
-                                                                               gboolean     arg_4,
-                                                                               gboolean     arg_5,
-                                                                               gboolean     arg_6,
-                                                                               gpointer     data2);
-  register GMarshalFunc_VOID__INT_LONG_BOOLEAN_BOOLEAN_BOOLEAN_BOOLEAN callback;
-  register GCClosure *cc = (GCClosure*) closure;
-  register gpointer data1, data2;
-
-  g_return_if_fail (n_param_values == 7);
-
-  if (G_CCLOSURE_SWAP_DATA (closure))
-    {
-      data1 = closure->data;
-      data2 = g_value_peek_pointer (param_values + 0);
-    }
-  else
-    {
-      data1 = g_value_peek_pointer (param_values + 0);
-      data2 = closure->data;
-    }
-  callback = (GMarshalFunc_VOID__INT_LONG_BOOLEAN_BOOLEAN_BOOLEAN_BOOLEAN) (marshal_data ? marshal_data : cc->callback);
-
-  callback (data1,
-            g_marshal_value_peek_int (param_values + 1),
-            g_marshal_value_peek_long (param_values + 2),
-            g_marshal_value_peek_boolean (param_values + 3),
-            g_marshal_value_peek_boolean (param_values + 4),
-            g_marshal_value_peek_boolean (param_values + 5),
-            g_marshal_value_peek_boolean (param_values + 6),
-            data2);
-}
-
